@@ -157,20 +157,24 @@ class pieMainWindow(wx.Frame):
         menuBar = wx.MenuBar()
         fileMenu = wx.Menu()
         toolMenu = wx.Menu()
+        helpMenu = wx.Menu()
         self.menu_savebibs = wx.MenuItem(fileMenu, -1, '&Save Bibliography Changes [%s]\tCtrl-s' % os.path.basename(config.get('PBoptions', 'default_bibliography')), 'Save')
         self.menu_savebibs.SetBitmap(wx.ArtProvider.GetBitmap(wx.ART_FILE_SAVE, wx.ART_MENU, (16, 16)))
         self.menu_discard = wx.MenuItem(fileMenu, -1, '&Discard Bibliography Changes', 'Discard')
         self.menu_quit = wx.MenuItem(fileMenu, -1, '&Quit\tCtrl-q', 'Quit')
         self.menu_quit.SetBitmap(wx.ArtProvider.GetBitmap(wx.ART_QUIT, wx.ART_MENU))
         self.menu_config = wx.MenuItem(fileMenu, -1, 'S&ettings', 'Config')
-        self.menu_about = wx.MenuItem(fileMenu, -1, '&About', 'About')
+        self.menu_about = wx.MenuItem(helpMenu, -1, '&About', 'About')
         self.menu_pageref = wx.MenuItem(toolMenu, -1, 'Create &reference for top-level page', 'Reference')
         self.menu_emptyref = wx.MenuItem(toolMenu, -1, '&Create new (empty) bibliography entry\tCtrl-n', 'Newref')
         self.menu_emptyref.SetBitmap(wx.ArtProvider.GetBitmap(wx.ART_NEW, wx.ART_MENU))
+        self.menu_manual = wx.MenuItem(helpMenu, -1, '&Manual')
+        helpMenu.AppendItem(self.menu_manual)
         fileMenu.AppendItem(self.menu_savebibs)
         fileMenu.AppendItem(self.menu_discard)
         fileMenu.AppendItem(self.menu_config)
-        fileMenu.AppendItem(self.menu_about)
+        helpMenu.AppendItem(self.menu_about)
+        fileMenu.AppendSeparator()
         fileMenu.AppendItem(self.menu_quit)
         toolMenu.AppendItem(self.menu_emptyref)
         toolMenu.AppendItem(self.menu_pageref)
@@ -195,6 +199,7 @@ class pieMainWindow(wx.Frame):
             menuBar.Append(atomMenu, '&Desktop cleaner')
             self.Bind(wx.EVT_MENU, self.onAtomProcess, self.menu_atom_process)
             self.Bind(wx.EVT_MENU, self.onAtomSettings, self.menu_atom_settings)
+        menuBar.Append(helpMenu, '&Help')
         self.SetMenuBar(menuBar)
         self.SetAutoLayout(True)
         self.Bind(wx.EVT_MENU, self.onSaveBibs, self.menu_savebibs)
@@ -204,6 +209,7 @@ class pieMainWindow(wx.Frame):
         self.Bind(wx.EVT_MENU, self.onDiscard, self.menu_discard)
         self.Bind(wx.EVT_MENU, self.onPageReference, self.menu_pageref)
         self.Bind(wx.EVT_MENU, self.onEmptyReference, self.menu_emptyref)
+        self.Bind(wx.EVT_MENU, self.onShowManual, self.menu_manual)
         self.menu_savebibs.Enable(False)
         self.menu_discard.Enable(False)
 
@@ -446,6 +452,11 @@ class pieMainWindow(wx.Frame):
         self.menu_savebibs.Enable(False)
         self.menu_discard.Enable(False)
 
+    def onShowManual(self, evt):
+        import wx.html
+        self.hctrl = wx.html.HtmlHelpController()
+        self.hctrl.AddBook(os.path.join(HELPDIR, 'pieberrymanual.hhp'))
+        self.hctrl.Display(os.path.join(HELPDIR, 'manual.html'))
 
     def onAddFile(self, filename):
         '''dnd action'''
@@ -483,7 +494,7 @@ class pieMainWindow(wx.Frame):
                 shutil.copyfile(filename, pdf['final_fn'])
                 if not pdf.has_key('annote'):
                     pdf['annote'] = ''
-                pdf['annote'] = pdf['annote'] + 'Saved_to: %s' % pdf['final_fn']
+                pdf['annote'] = pdf['annote'] + 'Saved_to: %s' % os.path.relpath(pdf['final_fn'], config.get('PBoptions', 'workingdir'))
                 self.allData[data_id] = pdf
                 wx.PostEvent(self, pieUpdateEvent('success', 'Success', cite="%s (%s). %s" % (pdf['author'], pdf['year'], pdf['title']), data_id=data_id, updatelast=True))
             except:
@@ -545,7 +556,7 @@ class pieMainWindow(wx.Frame):
     def onAbout(self, evt):
         info = wx.AboutDialogInfo()
         info.AddDeveloper('Raif Sarcich')
-        info.SetVersion('1.7-3')
+        info.SetVersion('1.7-7')
         info.SetCopyright('(c) 2010 Raif Sarcich et. al.')
         info.SetLicence('''This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -1138,8 +1149,9 @@ class pieNewConfigDialog(pieConfigDialog):
 #         self.out.WriteText(string)
 
 def main(argv):
-    # sys.stdout = open(os.path.join(sysdir, 'stdlog.txt'), 'w')
-    # sys.stderr = open(os.path.join(sysdir, 'errlog.txt'), 'w')
+    if PY2EXE:
+        sys.stdout = open(os.path.join(sysdir, 'stdlog.txt'), 'w')
+        sys.stderr = open(os.path.join(sysdir, 'errlog.txt'), 'w')
     app = wx.App(redirect=False)
     w = pieMainWindow()
     w.Show()
