@@ -63,12 +63,21 @@ def pybtex_to_pieberry(key, ent):
         for person in persons:
             person.text = unicode(person)
     for k, v in ent.fields.items():
+        # print 'unicode', v
+        # print 'utf8', v.encode('utf-8')
+        # print 'cp1252', v.encode('cp1252')
+        # try:
+        #     assert type(v) == unicode
+        # except:
+        #     v = unicode(v, 'utf-8')
         if k in bibtex_fields:
             ret[k] = ublc(v)
         if k == 'annote':
             filehere = re_fileloc.search(ublc(v))
             if filehere:
-                ret['final_fn'] = ublc(filehere.group(1))
+                ret['final_fn'] = os.path.join(config.get('PBoptions', 'workingdir'), ublc(filehere.group(1)))
+#                print 'establishing fileloc ', ret['final_fn'], config.get('PBoptions', 'workingdir')
+#                print 'WTF ', os.path.join(config.get('PBoptions', 'workingdir'), ublc(filehere.group(1)))
             datehere = re_pubdate.search(v)
             try:
                 if datehere:
@@ -278,7 +287,7 @@ def exec_search(searchdict, entries):
     return ranked
     
 def pybtex_entries_from_file(filename):
-    parser = bibtex.Parser()
+    parser = bibtex.Parser(encoding='utf-8')
     bib_data = parser.parse_file(filename)
     return bib_data.entries
 
@@ -286,7 +295,7 @@ def get_formatted_citation(e):
     return get_formatted_citation_html(e)
 
 def get_formatted_citation_from_bibtex(bibtex_entry):
-    parser = bibtex.Parser()
+    parser = bibtex.Parser(encoding='utf-8')
     f = open(os.path.join(sysdir, 'temp.bib'), 'w')
     f.write(bibtex_entry)
     f.close()
